@@ -1,10 +1,14 @@
 #' Estimate Marginal Means (Model-based average at each factor level)
 #'
-#' Estimate average value of response variable at each factor levels. For plotting, check the examples in \code{\link{visualisation_recipe}}. See also other
-#' related functions such as \code{\link{estimate_contrasts}} and \code{\link{estimate_slopes}}.
+#' Estimate average value of response variable at each factor levels. For
+#' plotting, check the examples in [visualisation_recipe()]. See also
+#' other related functions such as [estimate_contrasts()] and
+#' [estimate_slopes()].
 #'
 #' @inheritParams model_emmeans
-#' @param ci Uncertainty Interval (CI) level. Default to 95\% (\code{0.95}).
+#' @inheritParams parameters::model_parameters.default
+#'
+#' @inherit estimate_slopes details
 #'
 #' @examples
 #' library(modelbased)
@@ -15,12 +19,12 @@
 #'
 #' estimate_means(model)
 #' estimate_means(model, fixed = "Sepal.Width")
-#' estimate_means(model, levels = c("Species", "Sepal.Width"), length = 2)
-#' estimate_means(model, levels = "Species=c('versicolor', 'setosa')")
-#' estimate_means(model, levels = "Sepal.Width=c(2, 4)")
-#' estimate_means(model, levels = c("Species", "Sepal.Width=0"))
-#' estimate_means(model, modulate = "Sepal.Width", length = 5)
-#' estimate_means(model, modulate = "Sepal.Width=c(2, 4)")
+#' estimate_means(model, at = c("Species", "Sepal.Width"), length = 2)
+#' estimate_means(model, at = "Species=c('versicolor', 'setosa')")
+#' estimate_means(model, at = "Sepal.Width=c(2, 4)")
+#' estimate_means(model, at = c("Species", "Sepal.Width=0"))
+#' estimate_means(model, at = "Sepal.Width", length = 5)
+#' estimate_means(model, at = "Sepal.Width=c(2, 4)")
 #'
 #' # Methods that can be applied to it:
 #' means <- estimate_means(model, fixed = "Sepal.Width")
@@ -33,59 +37,31 @@
 #'
 #'   model <- lmer(Petal.Length ~ Sepal.Width + Species + (1 | Petal.Length_factor), data = data)
 #'   estimate_means(model)
-#'   estimate_means(model, modulate = "Sepal.Width", length = 3)
-#' }
-#'
-#' # Bayesian models
-#' # -------------------
-#' data <- mtcars
-#' data$cyl <- as.factor(data$cyl)
-#' data$am <- as.factor(data$am)
-#'
-#' if (require("rstanarm")) {
-#'   model <- stan_glm(mpg ~ cyl * am, data = data, refresh = 0)
-#'   estimate_means(model)
-#'
-#'   model <- stan_glm(mpg ~ cyl * wt, data = data, refresh = 0)
-#'   estimate_means(model)
-#'   estimate_means(model, modulate = "wt")
-#'   estimate_means(model, fixed = "wt")
-#' }
-#' }
-#'
-#' \dontrun{
-#' if (require("brms")) {
-#'   model <- brm(mpg ~ cyl * am, data = data, refresh = 0)
-#'   estimate_means(model)
+#'   estimate_means(model, at = "Sepal.Width", length = 3)
 #' }
 #' }
 #'
 #' @return A dataframe of estimated marginal means.
 #' @export
 estimate_means <- function(model,
-                           levels = NULL,
+                           at = "auto",
                            fixed = NULL,
-                           modulate = NULL,
                            transform = "response",
                            ci = 0.95,
                            ...) {
 
-  # Sanitize arguments
-  args <- .guess_arguments(model, levels = levels, fixed = fixed, modulate = modulate)
-
   # Run emmeans
-  estimated <- model_emmeans(
-    model,
-    levels = args$levels,
-    fixed = args$fixed,
-    modulate = args$modulate,
-    transform = transform,
-    ...
-  )
+  estimated <- model_emmeans(model, at, fixed, transform = transform, ...)
+  info <- attributes(estimated)
 
   # Summarize and clean
   if (insight::model_info(model)$is_bayesian) {
-    means <- bayestestR::describe_posterior(estimated, test = NULL, rope_range = NULL, ci = ci, ...)
+    means <- bayestestR::describe_posterior(estimated,
+      test = NULL,
+      rope_range = NULL,
+      ci = ci,
+      ...
+    )
     means <- cbind(estimated@grid, means)
     means$`.wgt.` <- NULL # Drop the weight column
     means <- .clean_names_bayesian(means, model, transform, type = "mean")
@@ -94,23 +70,24 @@ estimate_means <- function(model,
     means$df <- NULL
     means <- .clean_names_frequentist(means)
   }
+  # Remove the "1 - overall" column that can appear in cases like at = NULL
+  means <- means[names(means) != "1"]
 
   # Restore factor levels
-  means <- insight::data_restoretype(means, insight::get_data(model))
+  means <- datawizard::data_restoretype(means, insight::get_data(model))
 
 
   # Table formatting
   attr(means, "table_title") <- c("Estimated Marginal Means", "blue")
-  attr(means, "table_footer") <- .estimate_means_footer(means, args, type = "means")
+  attr(means, "table_footer") <- .estimate_means_footer(means, info$at, type = "means")
 
   # Add attributes
   attr(means, "model") <- model
   attr(means, "response") <- insight::find_response(model)
   attr(means, "ci") <- ci
   attr(means, "transform") <- transform
-  attr(means, "levels") <- args$levels
-  attr(means, "fixed") <- args$fixed
-  attr(means, "modulate") <- args$modulate
+  attr(means, "at") <- info$at
+  attr(means, "fixed") <- info$fixed
   attr(means, "coef_name") <- intersect(c("Mean", "Probability"), names(means))
 
 
@@ -178,17 +155,15 @@ estimate_means <- function(model,
 # Table Formating ----------------------------------------------------------
 
 
-.estimate_means_footer <- function(x, args = NULL, type = "means", adjust = NULL) {
-  table_footer <- ""
+.estimate_means_footer <- function(x, at = NULL, type = "means", adjust = NULL) {
+  table_footer <- paste("\nMarginal", type)
 
   # Levels
-  if (length(args$levels) > 0) {
+  if (!is.null(at) && length(at) > 0) {
     table_footer <- paste0(
       table_footer,
-      "\nMarginal ",
-      type,
-      " estimated for ",
-      paste0(args$levels, collapse = ", ")
+      " estimated at ",
+      paste0(at, collapse = ", ")
     )
   }
 
