@@ -4,7 +4,7 @@
 
 #' @export
 visualisation_matrix.glm <- function(x,
-                                     target = "all",
+                                     at = "all",
                                      factors = "reference",
                                      numerics = "mean",
                                      preserve_range = TRUE,
@@ -13,27 +13,50 @@ visualisation_matrix.glm <- function(x,
                                      include_random = FALSE,
                                      include_response = FALSE,
                                      ...) {
+  # Retrieve data from model
   data <- insight::get_data(x)[insight::find_variables(x, "all", flatten = TRUE)]
 
+  # Deal with factor transformations
+  # f <- insight::find_terms(model)
+  data[] <- lapply(data, function(i) {
+    if (isTRUE(attributes(i)$factor)) {
+      as.factor(i)
+    } else {
+      i
+    }
+  })
+
+
+  # Deal with intercept-only models
   if (include_response == FALSE) {
     data <- data[!names(data) %in% insight::find_response(x)]
-  }
-
-  if (include_random == FALSE) {
-    data <- data[names(data) %in% insight::find_predictors(x, effects = "fixed", flatten = TRUE)]
-  }
-
-  if (all(target == "all")) target <- names(data)
-  if (include_smooth == FALSE || include_smooth == "fixed") {
-    s <- insight::find_smooth(x, flatten = TRUE)
-    if (!is.null(s)) {
-      target <- names(data)[!names(data) %in% insight::clean_names(s)]
+    if (ncol(data) < 1) {
+      stop(insight::format_message("Model only seems to be an intercept-only model. Use `include_response=TRUE` to create the visualization matrix."), call. = FALSE)
     }
   }
 
-  data <- visualisation_matrix(
+  # Drop random factors
+  if (include_random == FALSE) {
+    keep <- insight::find_predictors(x, effects = "fixed", flatten = TRUE)
+    if (!is.null(keep)) {
+      if (all(at != "all")) {
+        keep <- c(keep, at[at %in% insight::find_random(x, flatten = TRUE)])
+      }
+      data <- data[names(data) %in% keep]
+    }
+  }
+
+  if (all(at == "all")) at <- names(data)
+  if (include_smooth == FALSE || include_smooth == "fixed") {
+    s <- insight::find_smooth(x, flatten = TRUE)
+    if (!is.null(s)) {
+      at <- names(data)[!names(data) %in% insight::clean_names(s)]
+    }
+  }
+
+  vm <- visualisation_matrix(
     data,
-    target = target,
+    at = at,
     factors = factors,
     numerics = numerics,
     preserve_range = preserve_range,
@@ -42,11 +65,11 @@ visualisation_matrix.glm <- function(x,
   )
 
   if (include_smooth == FALSE) {
-    data[names(data) %in% insight::clean_names(insight::find_smooth(x, flatten = TRUE))] <- NULL
+    vm[names(vm) %in% insight::clean_names(insight::find_smooth(x, flatten = TRUE))] <- NULL
   }
 
-  attr(data, "model") <- x
-  data
+  attr(vm, "model") <- x
+  vm
 }
 
 
