@@ -40,7 +40,7 @@ if (require("testthat") && require("modelbased") && require("glmmTMB") && requir
   })
 
   test_that("estimate_slope - glmmTMB", {
-    estim <- estimate_slopes(model2, trend = "cover", transform = "response")
+    estim <- estimate_slopes(model2, trend = "cover", at = "mined", transform = "response")
     estim2 <- as.data.frame(emmeans::emtrends(model2, "mined", var = "cover", transform = "response"))
     expect_equal(estim$Coefficient, estim2$cover.trend, tolerance = 1e-2)
   })
